@@ -1,4 +1,4 @@
-"""A Python package for using complex numbers as vectors."""
+"""A package for using complex numbers as 2D vectors."""
 from __future__ import annotations
 
 import cmath
@@ -11,16 +11,7 @@ def convert_angle(angle, /, unit: str):
         return angle * cmath.tau / 360
     if unit in {"r", "", None, "rad", "radian", "radians"}:
         return angle
-    if unit in {
-        "g",
-        "grad",
-        "gradians",
-        "gradian",
-        "gons",
-        "gon",
-        "grades",
-        "grade",
-    }:
+    if unit in {"g", "grad", "gradians", "gradian", "gons", "gon", "grades", "grade"}:
         return angle * cmath.tau / 400
     if unit in {"mins", "min", "minutes", "minute", "'", "′"}:
         return angle * cmath.tau / 21600
@@ -95,19 +86,19 @@ class Vector(complex):
 
     def perp_dot(self, other: Vector, /) -> float:
         """
-        Get the perp dot product of self and other.
+        Return the perp dot product of self and other.
 
         This is the signed area of the parallelogram they define. It is
-        also one of the 'cross products' that can be defined on 2d
+        also one of the 'cross products' that can be defined on 2D
         vectors.
         """
         return self.real * other.imag - self.imag * other.real
 
     def perp(self, /) -> Vector:
         """
-        Get the vector, rotated anticlockwise by pi / 2.
+        Return the Vector, rotated anticlockwise by pi / 2.
 
-        This is one of the 'cross products' that can be defined on 2d
+        This is one of the 'cross products' that can be defined on 2D
         vectors. Use -Vector.perp() for a clockwise rotation.
         """
         return Vector(-self.imag, self.real)
@@ -121,6 +112,10 @@ class Vector(complex):
         angle = convert_angle(angle, unit)
         return Vector(r=self.r, theta=self.theta + angle)
 
+    def hat(self, /) -> Vector:
+        """Return a Vector with the same direction, but unit length."""
+        return self / abs(self)
+
     def rec(self, /) -> tuple[float, float]:
         """Get the vector as (x, y)."""
         return (self.real, self.imag)
@@ -139,19 +134,7 @@ class Vector(complex):
         return 2
 
     def __getitem__(self, key, /):
-        if isinstance(key, int):
-            if key in {0, -2}:
-                return self.real
-            if key in {1, -1}:
-                return self.imag
-            raise IndexError("Vector index out of range")
-
-        if isinstance(key, slice):
-            return self.rec()[key]
-
-        raise TypeError(
-            f"Vector indices must be integers or slices, not {key.__class__.__name__}"
-        )
+        return self.rec()[key]
 
     def __contains__(self, item, /):
         return item == self.real or item == self.imag
@@ -182,6 +165,12 @@ class Vector(complex):
     def __pow__(self, value, mod=None, /) -> Vector:
         return Vector(super().__pow__(value, mod))
 
+    __radd__ = __add__
+    __rsub__ = __sub__
+    __rmul__ = __mul__
+    __rtruediv__ = __truediv__
+    __rpow__ = __pow__
+
     @property
     def x(self) -> float:
         """The horizontal component of the vector."""
